==> humhub-1.6.4.tar.gz: humhub-1.6.4/protected/humhub/modules/user/messages/it/account.php <==
<?php
return array (
  '<strong>Account</strong> settings' => 'Impostazioni <strong>account</strong>',
  '<strong>Confirm</strong></strong> your new email address' => '<strong>Conferma</strong> il tuo nuovo indirizzo email',
  '<strong>Security</strong> settings' => 'Impostazioni <strong>Sicurezza</strong>',
  '<strong>User</strong> modules' => 'Moduli <strong>utente</strong>',
  '<strong>User</strong> settings' => '<strong>Impostazioni</strong> utente',
  '<strong>Your</strong> profile' => '<strong>Il tuo</strong> profilo',
  'All your personal data will be irrevocably deleted.' => 'Tutti i tuoi dati personali verranno definitivamente eliminati.',
  'Are you really sure? *ALL* module data for your profile will be deleted!' => 'Sei veramente sicuro? *Tutti* i dati dei moduli del tuo profilo saranno eliminati!',
  'Are you sure that you want to delete your account?' => 'Sei sicuro di voler eliminare il tuo account?',
  'Changing the username can make some links unusable, for example old links to the profile.' => 'La modifica del nome utente può rendere inutilizzabili alcuni collegamenti, ad esempio vecchi collegamenti al profilo.',
  'Configure' => 'Configura',
  'Confirm' => 'Conferma',
  'Current password' => 'Password attuale',
  'Delete account' => 'Elimina account',
  'Disable' => 'Disabilita',
  'Do you really want to delete your icon image?' => 'Vuoi veramente cancellare l\'immagine dell\'icona?',
  'Do you really want to delete your logo image?' => 'Vuoi veramente eliminare la tua immagine?',
  'E-Mail' => 'Email',
  'E-Mail change' => 'Cambia e-mail',
  'Enable' => 'Abilita',
  'Enhance your profile with modules.' => 'Potenzia il tuo profilo con i moduli.',
  'Enter your password to continue' => 'Inserisci la tua password per continuare',
  'Hello' => 'Ciao',
  'Here you can edit your general profile data, which is visible in the about page of your profile.' => 'Qui puoi modificare i tuoi dati generali del profile, che sono visibili nella pagina personale del tuo profilo.',
  'Here you can manage your account permissions for different user-types. To edit a permission, select the user-type you want to edit and change the drop-down value of the given permission.' => '',
  'Hide introduction tour panel on dashboard' => 'Nascondi il pannello tour introduttivo sulla bacheca',
  'Invalid link! Please make sure that you entered the entire url.' => 'Link non valido! Assicurati di aver inserito l\'intero URL.',
  'Language' => 'Lingua',
  'Modules' => 'Moduli',
  'New E-Mail address' => 'Nuovo indirizzo e-mail',
  'New User name' => 'Nuovo nome utente',
  'Not registered users' => 'Utenti non registrati',
  'Notifications' => 'Notifiche',
  'Other users' => 'Altri utenti',
  'Password Recovery' => 'Recupera password',
  'Profile' => 'Profilo',
  'Profile visibility' => 'Visibilità profilo',
  'Registered users only' => 'Solo utenti registrati',
  'Save' => 'Salva',
  'Save profile' => 'Salva il profilo',
  'Security' => 'Sicurezza',
  'Settings' => 'Impostazioni',
  'Tags' => 'Tag',
  'The entered e-mail address is already in use by another user.' => 'La mail inserita è già stata utilizzata da un altro utente.',
  'TimeZone' => 'Fuso orario',
  'Username has been changed' => 'Il nome utente è stato cambiato',
  'Users' => 'Persone',
  'Visible for all (also unregistered users)' => 'Visibile a tutti (anche utenti non registrati)',
  'We´ve just sent an confirmation e-mail to your new address. <br /> Please follow the instructions inside.' => 'Abbiamo inviato una conferma via e-mail al tuo nuovo indirizzo. <br />Per favore segui le istruzioni all\'interno.',
  'You are currently the owner of following spaces:' => 'Sei il proprietario dei seguenti spazi:',
  'You have requested to change your e-mail address.<br>Your new e-mail address is {newemail}.<br><br>To confirm your new e-mail address please click on the button below.' => 'Hai richiesto il cambiamento del tuo indirizzo email.<br />Il tuo nuovo indirizzo e-mail è {newemail}.<br /><br />Per confermare il tuo nuovo indirizzo e-mail per favore clicca sul pulsante qui sotto.',
  'You have successfully changed your username.<br>Your new username is {newUsername}.' => 'Hai cambiato correttamente il tuo nome utente.<br />Il tuo nuovo nome utente è {newUsername}.',
  'You must transfer ownership or delete these spaces before you can delete your account.' => 'Devi trasferire la proprietà o cancellare gli spazi prima di eliminare il tuo account.',
  'Your account cannot be deleted!' => 'Il tuo account non può essere eliminato!',
  'Your current E-mail address is <b>{email}</b>. You can change your current E-mail address here.' => 'La tua email attuale è <b>{email}</b>. Puoi modificarla qui.',
  'Your current password can be changed here.' => 'Puoi cambiare la tua password qui.',
  'Your current username is <b>{username}</b>. You can change your current username here.' => '',
  'Your e-mail address has been successfully changed to {email}.' => 'Il tuo indirizzo e-mail è stato cambiato con successo a {email}.',
  'Your friends' => 'I tuoi amici',
  'Your password has been successfully changed!' => 'La tua password è stata cambiata con successo!',
  'Your username has been changed' => 'Il tuo nome utente è stato cambiato',
  'Your username has been successfully changed. <br> We´ve just sent an e-mail to you with new information.' => 'Il tuo nome utente è stato modificato con successo. <br /> Ti abbiamo appena inviato una e-mail con le nuove informazioni.',
  '{attribute} "{value}" was not found!' => '{attribute} "{value}" non è stato trovato!',
);

==> humhub-1.8.1.tar.gz: humhub-1.8.1/protected/humhub/modules/user/messages/it/account.php <==
<?php
return array (
  '<strong>Account</strong> settings' => 'Impostazioni <strong>account</strong>',
  '<strong>Confirm</strong></strong> your new email address' => '<strong>Conferma</strong> il tuo nuovo indirizzo email',
  '<strong>Permissions</strong>' => '',
  '<strong>User</strong> modules' => 'Moduli <strong>utente</strong>',
  '<strong>User</strong> settings' => '<strong>Impostazioni</strong> utente',
  '<strong>Your</strong> profile' => '<strong>Il tuo</strong> profilo',
  'All your personal data will be irrevocably deleted.' => 'Tutti i tuoi dati personali verranno definitivamente eliminati.',
  'Are you really sure? *ALL* module data for your profile will be deleted!' => 'Sei veramente sicuro? *Tutti* i dati dei moduli del tuo profilo saranno eliminati!',
  'Are you sure that you want to delete your account?' => 'Sei sicuro di voler eliminare il tuo account?',
  'Changing the username can make some links unusable, for example old links to the profile.' => 'La modifica del nome utente può rendere inutilizzabili alcuni collegamenti, ad esempio vecchi collegamenti al profilo.',
  'Configure' => 'Configura',
  'Confirm' => 'Conferma',
  'Current password' => 'Password attuale',
  'Delete account' => 'Elimina account',
  'Disable' => 'Disabilita',
  'Do you really want to delete your icon image?' => 'Vuoi veramente cancellare l\'immagine dell\'icona?',
  'Do you really want to delete your logo image?' => 'Vuoi veramente eliminare la tua immagine?',
  'E-Mail' => 'Email',
  'E-Mail change' => 'Cambia e-mail',
  'Enable' => 'Abilita',
  'Enhance your profile with modules.' => 'Potenzia il tuo profilo con i moduli.',
  'Enter your password to continue' => 'Inserisci la tua password per continuare',
  'Hello' => 'Ciao',
  'Here you can edit your general profile data, which is visible in the about page of your profile.' => 'Qui puoi modificare i tuoi dati generali del profile, che sono visibili nella pagina personale del tuo profilo.',
  'Hide introduction tour panel on dashboard' => 'Nascondi il pannello tour introduttivo sulla bacheca',
  'Invalid link! Please make sure that you entered the entire url.' => 'Link non valido! Assicurati di aver inserito l\'intero URL.',
  'Language' => 'Lingua',
  'Modules' => 'Moduli',
  'New E-Mail address' => 'Nuovo indirizzo e-mail',
  'New User name' => 'Nuovo nome utente',
  'Not registered users' => 'Utenti non registrati',
  'Notifications' => 'Notifiche',
  'Other users' => 'Altri utenti',
  'Password Recovery' => 'Recupera password',
  'Permissions' => 'Permessi',
  'Profile' => 'Profilo',
  'Profile visibility' => 'Visibilità profilo',
  'Registered users only' => 'Solo utenti registrati',
  'Save' => 'Salva',
  'Save profile' => 'Salva il profilo',
  'Settings' => 'Impostazioni',
  'Tags' => 'Tag',
  'The entered e-mail address is already in use by another user.' => 'La mail inserita è già stata utilizzata da un altro utente.',
  'These settings allow you to determine which permissions you want to grant visitors of your own individual profile. Each user can freely adjust the settings for his or her own profile.' => '',
  'TimeZone' => 'Fuso orario',
  'Username has been changed' => 'Il nome utente è stato cambiato',
  'Users' => 'Persone',
  'Visible for all (also unregistered users)' => 'Visibile a tutti (anche utenti non registrati)',
  'We´ve just sent an confirmation e-mail to your new address. <br /> Please follow the instructions inside.' => 'Abbiamo inviato una conferma via e-mail al tuo nuovo indirizzo. <br />Per favore segui le istruzioni all\'interno.',
  'You are currently the owner of following spaces:' => 'Sei il proprietario dei seguenti spazi:',
  'You have requested to change your e-mail address.<br>Your new e-mail address is {newemail}.<br><br>To confirm your new e-mail address please click on the button below.' => 'Hai richiesto il cambiamento del tuo indirizzo email.<br />Il tuo nuovo indirizzo e-mail è {newemail}.<br /><br />Per confermare il tuo nuovo indirizzo e-mail per favore clicca sul pulsante qui sotto.',
  'You have successfully changed your username.<br>Your new username is {newUsername}.' => 'Hai cambiato correttamente il tuo nome utente.<br />Il tuo nuovo nome utente è {newUsername}.',
  'You must transfer ownership or delete these spaces before you can delete your account.' => 'Devi trasferire la proprietà o cancellare gli spazi prima di eliminare il tuo account.',
  'Your account cannot be deleted!' => 'Il tuo account non può essere eliminato!',
  'Your current E-mail address is <b>{email}</b>. You can change your current E-mail address here.' => 'La tua email attuale è <b>{email}</b>. Puoi modificarla qui.',
  'Your current password can be changed here.' => 'Puoi cambiare la tua password qui.',
  'Your current username is <b>{username}</b>. You can change your current username here.' => 'Il tuo nome utente corrente è <b> {username} </b>. Puoi cambiare il tuo nome utente corrente qui.',
  'Your e-mail address has been successfully changed to {email}.' => 'Il tuo indirizzo e-mail è stato cambiato con successo a {email}.',
  'Your friends' => 'I tuoi amici',
  'Your password has been successfully changed!' => 'La tua password è stata cambiata con successo!',
  'Your username has been changed' => 'Il tuo nome utente è stato cambiato',
  'Your username has been successfully changed. <br> We´ve just sent an e-mail to you with new information.' => 'Il tuo nome utente è stato modificato con successo. <br /> Ti abbiamo appena inviato una e-mail con le nuove informazioni.',
  '{attribute} "{value}" was not found!' => '{attribute} "{value}" non è stato trovato!',
);
